@@ -72,7 +72,7 @@ class BloomSkySensor(Entity):
         self._sensor_name = sensor_name
         self._name = "{} {}".format(device["DeviceName"], sensor_name)
         self._state = None
-        self._unique_id = "{}-{}".format(self._device_id, self._sensor_name)
+        self._unique_id = f"{self._device_id}-{self._sensor_name}"
 
     @property
     def unique_id(self):
@@ -103,6 +103,6 @@ class BloomSkySensor(Entity):
         state = self._bloomsky.devices[self._device_id]["Data"][self._sensor_name]
 
         if self._sensor_name in FORMAT_NUMBERS:
-            self._state = "{0:.2f}".format(state)
+            self._state = f"{state:.2f}"
         else:
             self._state = state
