@@ -3,6 +3,8 @@ import copy
 from datetime import timedelta
 import logging
 
+from httplib2 import ServerNotFoundError  # pylint: disable=import-error
+
 from homeassistant.components.calendar import (
     ENTITY_ID_FORMAT,
     CalendarEventDevice,
@@ -126,9 +128,6 @@ class GoogleCalendarData:
         self.event = None
 
     def _prepare_query(self):
-        # pylint: disable=import-error
-        from httplib2 import ServerNotFoundError
-
         try:
             service = self.calendar_service.get()
         except ServerNotFoundError:
