@@ -9,6 +9,9 @@ import time
 import uuid
 
 from aiohttp.hdrs import AUTHORIZATION
+import jwt
+from pywebpush import WebPusher
+from py_vapid import Vapid
 import voluptuous as vol
 from voluptuous.humanize import humanize_error
 
@@ -56,7 +59,7 @@ def gcm_api_deprecated(value):
             "Configuring html5_push_notifications via the GCM api"
             " has been deprecated and will stop working after April 11,"
             " 2019. Use the VAPID configuration instead. For instructions,"
-            " see https://www.home-assistant.io/components/notify.html5/"
+            " see https://www.home-assistant.io/integrations/html5/"
         )
     return value
 
@@ -311,7 +314,6 @@ class HTML5PushCallbackView(HomeAssistantView):
 
     def decode_jwt(self, token):
         """Find the registration that signed this JWT and return it."""
-        import jwt
 
         # 1.  Check claims w/o verifying to see if a target is in there.
         # 2.  If target in claims, attempt to verify against the given name.
@@ -335,7 +337,6 @@ class HTML5PushCallbackView(HomeAssistantView):
     # https://auth0.com/docs/quickstart/backend/python
     def check_authorization_header(self, request):
         """Check the authorization header."""
-        import jwt
 
         auth = request.headers.get(AUTHORIZATION, None)
         if not auth:
@@ -491,7 +492,6 @@ class HTML5NotificationService(BaseNotificationService):
 
     def _push_message(self, payload, **kwargs):
         """Send the message."""
-        from pywebpush import WebPusher
 
         timestamp = int(time.time())
         ttl = int(kwargs.get(ATTR_TTL, DEFAULT_TTL))
@@ -550,7 +550,6 @@ class HTML5NotificationService(BaseNotificationService):
 
 def add_jwt(timestamp, target, tag, jwt_secret):
     """Create JWT json to put into payload."""
-    import jwt
 
     jwt_exp = datetime.fromtimestamp(timestamp) + timedelta(days=JWT_VALID_DAYS)
     jwt_claims = {
@@ -565,7 +564,6 @@ def add_jwt(timestamp, target, tag, jwt_secret):
 
 def create_vapid_headers(vapid_email, subscription_info, vapid_private_key):
     """Create encrypted headers to send to WebPusher."""
-    from py_vapid import Vapid
 
     if vapid_email and vapid_private_key and ATTR_ENDPOINT in subscription_info:
         url = urlparse(subscription_info.get(ATTR_ENDPOINT))
