@@ -17,7 +17,6 @@ from homeassistant.const import CONTENT_TYPE_JSON
 from homeassistant.core import Context, is_callback
 from homeassistant.helpers.json import JSONEncoder
 
-from .ban import process_success_login
 from .const import KEY_AUTHENTICATED, KEY_HASS, KEY_REAL_IP
 
 _LOGGER = logging.getLogger(__name__)
@@ -106,13 +105,8 @@ def request_handler_factory(view, handler):
 
         authenticated = request.get(KEY_AUTHENTICATED, False)
 
-        if view.requires_auth:
-            if authenticated:
-                if "deprecate_warning_message" in request:
-                    _LOGGER.warning(request["deprecate_warning_message"])
-                await process_success_login(request)
-            else:
-                raise HTTPUnauthorized()
+        if view.requires_auth and not authenticated:
+            raise HTTPUnauthorized()
 
         _LOGGER.debug(
             "Serving %s to %s (auth: %s)",
