@@ -3,6 +3,8 @@ import asyncio
 import logging
 from datetime import timedelta
 
+from RMVtransport import RMVtransport
+from RMVtransport.rmvtransport import RMVtransportApiConnectionError
 import voluptuous as vol
 
 from homeassistant.components.sensor import PLATFORM_SCHEMA
@@ -157,7 +159,7 @@ class RMVDepartureSensor(Entity):
         """Return the state attributes."""
         try:
             return {
-                "next_departures": [val for val in self.data.departures[1:]],
+                "next_departures": self.data.departures[1:],
                 "direction": self.data.departures[0].get("direction"),
                 "line": self.data.departures[0].get("line"),
                 "minutes": self.data.departures[0].get("minutes"),
@@ -208,8 +210,6 @@ class RMVDepartureData:
         timeout,
     ):
         """Initialize the sensor."""
-        from RMVtransport import RMVtransport
-
         self.station = None
         self._station_id = station_id
         self._destinations = destinations
@@ -224,14 +224,12 @@ class RMVDepartureData:
     @Throttle(SCAN_INTERVAL)
     async def async_update(self):
         """Update the connection data."""
-        from RMVtransport.rmvtransport import RMVtransportApiConnectionError
-
         try:
             _data = await self.rmv.get_departures(
                 self._station_id,
                 products=self._products,
-                directionId=self._direction,
-                maxJourneys=50,
+                direction_id=self._direction,
+                max_journeys=50,
             )
         except RMVtransportApiConnectionError:
             self.departures = []
