@@ -7,18 +7,15 @@ import async_timeout
 import voluptuous as vol
 
 from homeassistant import config_entries
-
 from .const import (
     CONF_IMPORT_GROUPS,
     CONF_IDENTITY,
     CONF_HOST,
     CONF_KEY,
     CONF_GATEWAY_ID,
+    KEY_SECURITY_CODE,
 )
 
-KEY_SECURITY_CODE = "security_code"
-KEY_IMPORT_GROUPS = "import_groups"
-
 
 class AuthError(Exception):
     """Exception if authentication occurs."""
@@ -83,7 +80,7 @@ class FlowHandler(config_entries.ConfigFlow):
         """Handle zeroconf discovery."""
         host = user_input["host"]
 
-        # pylint: disable=unsupported-assignment-operation
+        # pylint: disable=no-member # https://github.com/PyCQA/pylint/issues/3167
         self.context["host"] = host
 
         if any(host == flow["context"]["host"] for flow in self._async_in_progress()):
