@@ -6,7 +6,7 @@ from homeassistant.core import callback
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
 from homeassistant.helpers.entity import Entity
 
-from .const import DATA_TRANSMISSION, DATA_UPDATED, DOMAIN, SENSOR_TYPES
+from .const import DOMAIN, SENSOR_TYPES
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -19,7 +19,7 @@ async def async_setup_platform(hass, config, async_add_entities, discovery_info=
 async def async_setup_entry(hass, config_entry, async_add_entities):
     """Set up the Transmission sensors."""
 
-    transmission_api = hass.data[DOMAIN][DATA_TRANSMISSION]
+    tm_client = hass.data[DOMAIN][config_entry.entry_id]
     name = config_entry.data[CONF_NAME]
 
     dev = []
@@ -27,7 +27,7 @@ async def async_setup_entry(hass, config_entry, async_add_entities):
         dev.append(
             TransmissionSensor(
                 sensor_type,
-                transmission_api,
+                tm_client,
                 name,
                 SENSOR_TYPES[sensor_type][0],
                 SENSOR_TYPES[sensor_type][1],
@@ -41,17 +41,12 @@ class TransmissionSensor(Entity):
     """Representation of a Transmission sensor."""
 
     def __init__(
-        self,
-        sensor_type,
-        transmission_api,
-        client_name,
-        sensor_name,
-        unit_of_measurement,
+        self, sensor_type, tm_client, client_name, sensor_name, unit_of_measurement
     ):
         """Initialize the sensor."""
         self._name = sensor_name
         self._state = None
-        self._transmission_api = transmission_api
+        self._tm_client = tm_client
         self._unit_of_measurement = unit_of_measurement
         self._data = None
         self.client_name = client_name
@@ -62,6 +57,11 @@ class TransmissionSensor(Entity):
         """Return the name of the sensor."""
         return f"{self.client_name} {self._name}"
 
+    @property
+    def unique_id(self):
+        """Return the unique id of the entity."""
+        return f"{self._tm_client.api.host}-{self.name}"
+
     @property
     def state(self):
         """Return the state of the sensor."""
@@ -80,12 +80,14 @@ class TransmissionSensor(Entity):
     @property
     def available(self):
         """Could the device be accessed during the last update call."""
-        return self._transmission_api.available
+        return self._tm_client.api.available
 
     async def async_added_to_hass(self):
         """Handle entity which will be added."""
         async_dispatcher_connect(
-            self.hass, DATA_UPDATED, self._schedule_immediate_update
+            self.hass,
+            self._tm_client.api.signal_options_update,
+            self._schedule_immediate_update,
         )
 
     @callback
@@ -94,12 +96,12 @@ class TransmissionSensor(Entity):
 
     def update(self):
         """Get the latest data from Transmission and updates the state."""
-        self._data = self._transmission_api.data
+        self._data = self._tm_client.api.data
 
         if self.type == "completed_torrents":
-            self._state = self._transmission_api.get_completed_torrent_count()
+            self._state = self._tm_client.api.get_completed_torrent_count()
         elif self.type == "started_torrents":
-            self._state = self._transmission_api.get_started_torrent_count()
+            self._state = self._tm_client.api.get_started_torrent_count()
 
         if self.type == "current_status":
             if self._data:
